<!DOCTYPE kpartgui ><kpartgui name="krec" version="1">
<MenuBar>
	<Menu name="file">
		<Action name="export_file" />
		<Separator />
	</Menu>
	<Menu name="play">
		<text>&amp;Play</text>
		<Action name="player_play" />
		<Action name="player_record" />
		<Action name="player_stop" />
		<Separator />
		<Action name="player_gobegin" />
		<Action name="player_goend" />
		<Separator />
		<Action name="play_thru" />
	</Menu>
	<Menu name="tools">
		<Action name="artssupport_view_audiomanager" />
		<Separator />
		<Action name="exec_artscontrol" />
		<Action name="exec_kmix" />
	</Menu>
  <Menu name="settings">
 </Menu>
</MenuBar>
<ToolBar name="mainToolBar">
	<text>Main Toolbar</text>
	<Action name="file_save_as" />
	<Action name="export_file" />
	<Separator />
	<Action name="file_close" />
</ToolBar>
<ToolBar name="play">
	<text>Play</text>
	<Action name="player_play" />
	<Action name="player_record" />
	<Action name="player_stop" />
	<Action name="player_gobegin" />
	<Action name="player_goend" />
</ToolBar>
<ToolBar name="compressor">
	<text>Compressor</text>
</ToolBar>
<ActionProperties>
	<Action name="export_file" icon="fileexport" />
	<Action name="player_play" icon="player_play" />
	<Action name="player_record" icon="krec_record" />
	<Action name="player_stop" icon="player_stop" />
	<Action name="play_thru" icon="kmix" />
	<Action name="player_gobegin" icon="player_start" />
	<Action name="player_goend" icon="player_end" />
	<Action name="settings_startup" icon="wizard" />
	<Action name="exec_artscontrol" icon="artscontrol" />
	<Action name="exec_kmix" icon="kmix" />
</ActionProperties>
</kpartgui>
