# Playlist screen section
PlaylistBmp sgplist.png
PlaylistBmpPressed sgplist2.png

# Command : PlaylistWindowText <X> <Y> <MaxX> <MaxY>
# Desc.   : Where all the playlist files will be placed on the playlist
#           screen
PlaylistWindowText 43 42 170 211
PlaylistWindowFontName Arial
PlaylistWindowFontSize 12
PlaylistWindowFontYSpacing 10
PlaylistWindowNbSelectedTrack 79 215 93 225
PlaylistWindowNbTotalTracks 79 230 93 240

PlaylistWindowLinkButton 180 33 194 48
PlaylistWindowCloseButton 174 21 187 35
PlaylistWindowUpButton 146 226 179 242
PlaylistWindowDownButton 146 243 179 259
PlaylistWindowShuffleButton 189 175 233 185
PlaylistWindowSortButton 188 144 234 155
PlaylistWindowSortInverseButton 187 159 234 170
PlaylistWindowMinimizeButton 184 50 193 59
PlaylistWindowAddButton 188 74 234 84
PlaylistWindowDelButton 189 87 234 99
PlaylistWindowResetButton 192 102 232 113
PlaylistWindowLoadPlaylistButton 191 129 231 141
PlaylistWindowSavePlaylistButton 189 115 232 127
PlaylistWindowSelectionUpButton 27 42 41 55
PlaylistWindowSelectionDownButton 27 198 41 211
PlaylistWindowAboutButton 194 29 217 59
PlaylistWindowPlayButton 113 285 147 311
PlaylistWindowPreviousButton 76 285 109 310
PlaylistWindowNextButton 153 283 185 308
PlaylistWindowPauseButton 187 266 217 290
PlaylistWindowStopButton 198 239 234 262
PlaylistWindowOpenButton 202 210 236 233
PlaylistWindowColor 0 0 0
PlaylistWindowCurrentTrackColor 0 0 136
PlaylistWindowCurrentSelectionColor 153 207 181
