<!DOCTYPE kpartgui>
<kpartgui name="artscontrol" version="3">
<MenuBar>
  <Menu name="view"><text>&amp;View</text>
    <Action name="artssupport_view_scopeview"/>
    <Action name="artssupport_view_audiomanager"/>
    <Action name="artssupport_view_artsstatus"/>
    <Action name="artssupport_view_midimanager"/>
    <Action name="artssupport_view_environment"/>
    <Action name="artssupport_view_mediatypes"/>
    <Action name="view_freeverb"/>
    <Action name="old_volume_display"/>
    <Separator />
    <Action name="quit_artscontrol"/>
  </Menu>
</MenuBar>
</kpartgui>
