<!DOCTYPE kpartgui>
<!--
vim: syntax=xml
-->
<kpartgui name="noatunexcellent" version="4">
<MenuBar>
	<Menu name="file" noMerge="1"><text>&amp;File</text>
		<Action name="file_open"/>
		<Separator lineSeparator="true"/>
		<Action name="file_quit"/>
	</Menu>
	<Menu name="go_music" noMerge="1"><text>&amp;Go</text>
		<Action name="back"/>
		<Action name="stop"/>
		<Action name="play"/>
		<Action name="pause"/>
		<Action name="forward"/>
	</Menu>
	<Menu name="settings" noMerge="1"><text>&amp;Settings</text>
                <Merge name="StandardToolBarMenuHandler" />
		<Action name="options_show_toolbar"/>
		<Action name="options_show_menubar"/>
		<Action name="show_playlist"/>
		<Action name="show_volumecontrol"/>
		<Separator lineSeparator="true"/>
		<Action name="effects"/>
		<Action name="equalizer"/>
		<Action name="loop_style"/>
		<Separator lineSeparator="true"/>
		<Action name="options_configure"/>
	</Menu>
</MenuBar>
<Toolbar name="main"><text>Main Toolbar</text>
	<Action name="back"/>
	<Action name="stop"/>
	<Action name="play"/>
	<Action name="pause"/>
	<Action name="forward"/>
	<Separator lineSeparator="true"/>
	<Action name="file_open"/>
	<Action name="show_playlist"/>
	<Separator lineSeparator="true"/>
	<Action name="loop_style"/>
</Toolbar>
</kpartgui>
