<!DOCTYPE kpartgui>
<kpartgui name="kmid" version="3">
<MenuBar>
  <Menu name="file"><text>&amp;File</text>
    <Action name="file_save_lyrics"/>
  </Menu>
  <Menu name="song"><text>&amp;Song</text>
    <Action name="song_play"/>
    <Action name="song_pause"/>
    <Action name="song_stop"/>
    <Action name="song_previous"/>
    <Action name="song_next"/>
    <Action name="song_loop"/>
 </Menu>
 <Menu name="collections"><text>&amp;Collections</text>
    <Action name="collect_organize"/>
    <Action name="play_order"/>
    <Action name="collect_autoadd"/>
 </Menu>
 <Menu name="settings">
    <Action name="toggle_volumebar" append="show_merge"/>
    <Action name="toggle_channelview" append="show_merge"/>
    <Action name="file_type" append="save_merge"/>
    <Action name="display_events" append="save_merge"/>
    <Action name="option_automatictext" append="save_merge"/>
    <Separator append="save_merge"/>
    <Action name="channelview_options" append="save_merge"/>
    <Action name="change_font" append="save_merge"/>
    <Action name="midi_setup" append="save_merge"/>
 </Menu>
</MenuBar>
<ToolBar fullWidth="true" name="mainToolBar"><text>Main Toolbar</text>
    <Action name="song_previous"/>
    <Action name="song_rewind"/>
    <Action name="song_stop"/>
    <Action name="song_pause"/>
    <Action name="song_play"/>
    <Action name="song_forward"/>
    <Action name="song_next"/>
    <Separator/>
    <Action name="toggle_volumebar"/>
    <Action name="toggle_channelview"/>
</ToolBar>
</kpartgui>
