( cd usr/lib ; rm -rf libkcddb.so )
( cd usr/lib ; ln -sf libkcddb.so.1.0.0 libkcddb.so )
( cd usr/lib ; rm -rf libartsgui.so.0 )
( cd usr/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so.0 )
( cd usr/lib ; rm -rf libartsmodulescommon.so )
( cd usr/lib ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so )
( cd usr/lib ; rm -rf libartsmidi_idl.so )
( cd usr/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so )
( cd usr/lib ; rm -rf libartsmidi.so )
( cd usr/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so )
( cd usr/lib ; rm -rf libnoatun.so )
( cd usr/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so )
( cd usr/lib ; rm -rf libmpeg.so )
( cd usr/lib ; ln -sf libmpeg-0.3.0.so libmpeg.so )
( cd usr/lib ; rm -rf libartscontrolsupport.so )
( cd usr/lib ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so )
( cd usr/lib ; rm -rf libnoatuncontrols.so )
( cd usr/lib ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so )
( cd usr/lib ; rm -rf libartsmidi_idl.so.0 )
( cd usr/lib ; ln -sf libartsmidi_idl.so.0.0.0 libartsmidi_idl.so.0 )
( cd usr/lib ; rm -rf libartsgui_idl.so )
( cd usr/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so )
( cd usr/lib ; rm -rf libartsmodulesmixers.so.0 )
( cd usr/lib ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so.0 )
( cd usr/lib ; rm -rf libartsgui_kde.so )
( cd usr/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so )
( cd usr/lib ; rm -rf libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib-0.3.0.so.0 )
( cd usr/lib ; rm -rf libartsmodulescommon.so.0 )
( cd usr/lib ; ln -sf libartsmodulescommon.so.0.0.0 libartsmodulescommon.so.0 )
( cd usr/lib ; rm -rf libartscontrolsupport.so.1 )
( cd usr/lib ; ln -sf libartscontrolsupport.so.1.0.0 libartscontrolsupport.so.1 )
( cd usr/lib ; rm -rf libartsmodulessynth.so.0 )
( cd usr/lib ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so.0 )
( cd usr/lib ; rm -rf libkmidlib.so )
( cd usr/lib ; ln -sf libkmidlib.so.0.0.0 libkmidlib.so )
( cd usr/lib ; rm -rf libnoatuntags.so.1 )
( cd usr/lib ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so.1 )
( cd usr/lib ; rm -rf libkmidlib.so.0 )
( cd usr/lib ; ln -sf libkmidlib.so.0.0.0 libkmidlib.so.0 )
( cd usr/lib ; rm -rf libartscontrolapplet.so )
( cd usr/lib ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so )
( cd usr/lib ; rm -rf libartsmoduleseffects.so.0 )
( cd usr/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so.0 )
( cd usr/lib ; rm -rf libartsmodules.so.0 )
( cd usr/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so.0 )
( cd usr/lib ; rm -rf libnoatuncontrols.so.1 )
( cd usr/lib ; ln -sf libnoatuncontrols.so.1.2.0 libnoatuncontrols.so.1 )
( cd usr/lib ; rm -rf libnoatuntags.so )
( cd usr/lib ; ln -sf libnoatuntags.so.1.2.0 libnoatuntags.so )
( cd usr/lib ; rm -rf libkcddb.so.1 )
( cd usr/lib ; ln -sf libkcddb.so.1.0.0 libkcddb.so.1 )
( cd usr/lib ; rm -rf libartsmodules.so )
( cd usr/lib ; ln -sf libartsmodules.so.0.0.0 libartsmodules.so )
( cd usr/lib ; rm -rf libartsgui_idl.so.0 )
( cd usr/lib ; ln -sf libartsgui_idl.so.0.0.0 libartsgui_idl.so.0 )
( cd usr/lib ; rm -rf libarts_splay.so )
( cd usr/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so )
( cd usr/lib ; rm -rf libartsgui.so )
( cd usr/lib ; ln -sf libartsgui.so.0.0.0 libartsgui.so )
( cd usr/lib ; rm -rf libartsgui_kde.so.0 )
( cd usr/lib ; ln -sf libartsgui_kde.so.0.0.0 libartsgui_kde.so.0 )
( cd usr/lib ; rm -rf libaudiocdplugins.so.1 )
( cd usr/lib ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so.1 )
( cd usr/lib ; rm -rf libarts_splay.so.0 )
( cd usr/lib ; ln -sf libarts_splay.so.0.0.0 libarts_splay.so.0 )
( cd usr/lib ; rm -rf libartsmidi.so.0 )
( cd usr/lib ; ln -sf libartsmidi.so.0.0.0 libartsmidi.so.0 )
( cd usr/lib ; rm -rf libartsbuilder.so.0 )
( cd usr/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so.0 )
( cd usr/lib ; rm -rf libartsmodulesmixers.so )
( cd usr/lib ; ln -sf libartsmodulesmixers.so.0.0.0 libartsmodulesmixers.so )
( cd usr/lib ; rm -rf libarts_mpeglib.so )
( cd usr/lib ; ln -sf libarts_mpeglib-0.3.0.so.0.0.3 libarts_mpeglib.so )
( cd usr/lib ; rm -rf libarts_audiofile.so )
( cd usr/lib ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so )
( cd usr/lib ; rm -rf libnoatun.so.1 )
( cd usr/lib ; ln -sf libnoatun.so.1.2.0 libnoatun.so.1 )
( cd usr/lib ; rm -rf libaudiocdplugins.so )
( cd usr/lib ; ln -sf libaudiocdplugins.so.1.0.0 libaudiocdplugins.so )
( cd usr/lib ; rm -rf libartscontrolapplet.so.1 )
( cd usr/lib ; ln -sf libartscontrolapplet.so.1.0.0 libartscontrolapplet.so.1 )
( cd usr/lib ; rm -rf libartsbuilder.so )
( cd usr/lib ; ln -sf libartsbuilder.so.0.0.0 libartsbuilder.so )
( cd usr/lib ; rm -rf libartsmoduleseffects.so )
( cd usr/lib ; ln -sf libartsmoduleseffects.so.0.0.0 libartsmoduleseffects.so )
( cd usr/lib ; rm -rf libarts_audiofile.so.0 )
( cd usr/lib ; ln -sf libarts_audiofile.so.0.0.0 libarts_audiofile.so.0 )
( cd usr/lib ; rm -rf libartsmodulessynth.so )
( cd usr/lib ; ln -sf libartsmodulessynth.so.0.0.0 libartsmodulessynth.so )
( cd usr/share/doc/HTML/en/juk ; rm -rf common )
( cd usr/share/doc/HTML/en/juk ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmid ; rm -rf common )
( cd usr/share/doc/HTML/en/kmid ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kmix ; rm -rf common )
( cd usr/share/doc/HTML/en/kmix ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/krec ; rm -rf common )
( cd usr/share/doc/HTML/en/krec ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kscd ; rm -rf common )
( cd usr/share/doc/HTML/en/kscd ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kaboodle ; rm -rf common )
( cd usr/share/doc/HTML/en/kaboodle ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/artsbuilder ; rm -rf common )
( cd usr/share/doc/HTML/en/artsbuilder ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/kaudiocreator ; rm -rf common )
( cd usr/share/doc/HTML/en/kaudiocreator ; ln -sf /usr/share/doc/HTML/en/common common )
( cd usr/share/doc/HTML/en/noatun ; rm -rf common )
( cd usr/share/doc/HTML/en/noatun ; ln -sf /usr/share/doc/HTML/en/common common )
