<!DOCTYPE kpartgui>
<kpartgui name="Artsbuilder" version="3">
<MenuBar>
	<Menu name="file"><text>&amp;File</text>
		<Action name="file_open_example" append="new_merge"/>
		<Action name="file_execute_structure"/>
		<Action name="file_rename_structure"/>
		<!-- currently unused
		<Action name="file_open_session" append="new_merge"/>
		<Action name="file_publish_structure"/>
		<Action name="file_retrieve_from_server"/>
		-->
	</Menu>
	<Menu name="edit"><text>&amp;Edit</text>
		<Action name="edit_delete"/>
	</Menu>
	<Menu name="view"><text>&amp;View</text>
		<Action name="view_properties"/>
		<Separator/>
		<Action name="view_200"/>
		<Action name="view_150"/>
		<Action name="view_100"/>
		<Action name="view_50"/>
	</Menu>
	<Action name="modulesmenu"/>
	<!--
	<Menu name="modules"><text>&amp;Modules</text>
		<Action name="modulesmenu"/>
		<Separator/>
	</Menu>
	-->
	<Menu name="ports"><text>&amp;Ports</text>
		<Action name="ports_create_in_audio_signal"/>
		<Action name="ports_create_out_audio_signal"/>
		<Action name="ports_create_in_string_property"/>
		<Action name="ports_create_in_audio_property"/>
		<Separator/>
		<Action name="ports_implement_interface"/>
		<Separator/>
		<Action name="ports_change_positions"/>
	</Menu>
</MenuBar>
<ToolBar name="mainToolBar" ><text>Main Toolbar</text>
  <Separator />
  <Action name="file_execute_structure"/>
</ToolBar>
</kpartgui>
