/* this file was generated by the MCOP idl compiler - DO NOT EDIT */

#ifndef WINSKINVIS_H
#define WINSKINVIS_H

#include "common.h"

#include "arts_export.h"

// includes of other idl definitions
#include "artsflow.h"

namespace Noatun {
class WinSkinFFT;

class ARTS_EXPORT WinSkinFFT_base : virtual public Arts::StereoEffect_base {
public:
	static unsigned long _IID; // interface ID

	static WinSkinFFT_base *_create(const std::string& subClass = "Noatun::WinSkinFFT");
	static WinSkinFFT_base *_fromString(const std::string& objectref);
	static WinSkinFFT_base *_fromReference(Arts::ObjectReference ref, bool needcopy);

	static WinSkinFFT_base *_fromDynamicCast(const Arts::Object& object);
	inline WinSkinFFT_base *_copy() {
		assert(_refCnt > 0);
		_refCnt++;
		return this;
	}

	virtual std::vector<std::string> _defaultPortsIn() const;
	virtual std::vector<std::string> _defaultPortsOut() const;

	void *_cast(unsigned long iid);

	virtual float bandResolution() = 0;
	virtual void bandResolution(float newValue) = 0;
	virtual std::vector<float> * scope() = 0;
};

class ARTS_EXPORT WinSkinFFT_stub : virtual public WinSkinFFT_base, virtual public Arts::StereoEffect_stub {
protected:
	WinSkinFFT_stub();

public:
	WinSkinFFT_stub(Arts::Connection *connection, long objectID);

	float bandResolution();
	void bandResolution(float newValue);
	std::vector<float> * scope();
};

class ARTS_EXPORT WinSkinFFT_skel : virtual public WinSkinFFT_base, virtual public Arts::StereoEffect_skel {
protected:
	// emitters for change notifications
	inline void bandResolution_changed(float newValue) {
		_emit_changed("bandResolution_changed",newValue);
	}

public:
	WinSkinFFT_skel();

	static std::string _interfaceNameSkel();
	std::string _interfaceName();
	bool _isCompatibleWith(const std::string& interfacename);
	void _buildMethodTable();
	void dispatch(Arts::Buffer *request, Arts::Buffer *result,long methodID);
};

}
#include "reference.h"
namespace Noatun {
class ARTS_EXPORT WinSkinFFT : public Arts::Object {
private:
	static Arts::Object_base* _Creator();
	WinSkinFFT_base *_cache;
	inline WinSkinFFT_base *_method_call() {
		_pool->checkcreate();
		if(_pool->base) {
			_cache=(WinSkinFFT_base *)_pool->base->_cast(WinSkinFFT_base::_IID);
			assert(_cache);
		}
		return _cache;
	}

protected:
	inline WinSkinFFT(WinSkinFFT_base* b) : Arts::Object(b), _cache(0) {}


public:
	typedef WinSkinFFT_base _base_class;

	inline WinSkinFFT() : Arts::Object(_Creator), _cache(0) {}
	inline WinSkinFFT(const Arts::SubClass& s) :
		Arts::Object(WinSkinFFT_base::_create(s.string())), _cache(0) {}
	inline WinSkinFFT(const Arts::Reference &r) :
		Arts::Object(r.isString()?(WinSkinFFT_base::_fromString(r.string())):(WinSkinFFT_base::_fromReference(r.reference(),true))), _cache(0) {}
	inline WinSkinFFT(const Arts::DynamicCast& c) : Arts::Object(WinSkinFFT_base::_fromDynamicCast(c.object())), _cache(0) {}
	inline WinSkinFFT(const WinSkinFFT& target) : Arts::Object(target._pool), _cache(target._cache) {}
	inline WinSkinFFT(Arts::Object::Pool& p) : Arts::Object(p), _cache(0) {}
	inline static WinSkinFFT null() {return WinSkinFFT((WinSkinFFT_base*)0);}
	inline static WinSkinFFT _from_base(WinSkinFFT_base* b) {return WinSkinFFT(b);}
	inline WinSkinFFT& operator=(const WinSkinFFT& target) {
		if (_pool == target._pool) return *this;
		_pool->Dec();
		_pool = target._pool;
		_cache = target._cache;
		_pool->Inc();
		return *this;
	}
	inline operator Arts::StereoEffect() const { return Arts::StereoEffect(*_pool); }
	inline operator Arts::SynthModule() const { return Arts::SynthModule(*_pool); }
	inline WinSkinFFT_base* _base() {return _cache?_cache:_method_call();}

	inline Arts::AutoSuspendState autoSuspend();
	inline void start();
	inline void stop();
	inline void streamInit();
	inline void streamStart();
	inline void streamEnd();
	inline float bandResolution();
	inline void bandResolution(float _newValue);
	inline std::vector<float> * scope();
};

}
// Forward wrapper calls to _base classes:

inline Arts::AutoSuspendState Noatun::WinSkinFFT::autoSuspend()
{
	return _cache?static_cast<Arts::SynthModule_base*>(_cache)->autoSuspend():static_cast<Arts::SynthModule_base*>(_method_call())->autoSuspend();
}

inline void Noatun::WinSkinFFT::start()
{
	 _cache?static_cast<Arts::SynthModule_base*>(_cache)->start():static_cast<Arts::SynthModule_base*>(_method_call())->start();
}

inline void Noatun::WinSkinFFT::stop()
{
	 _cache?static_cast<Arts::SynthModule_base*>(_cache)->stop():static_cast<Arts::SynthModule_base*>(_method_call())->stop();
}

inline void Noatun::WinSkinFFT::streamInit()
{
	 _cache?static_cast<Arts::SynthModule_base*>(_cache)->streamInit():static_cast<Arts::SynthModule_base*>(_method_call())->streamInit();
}

inline void Noatun::WinSkinFFT::streamStart()
{
	 _cache?static_cast<Arts::SynthModule_base*>(_cache)->streamStart():static_cast<Arts::SynthModule_base*>(_method_call())->streamStart();
}

inline void Noatun::WinSkinFFT::streamEnd()
{
	 _cache?static_cast<Arts::SynthModule_base*>(_cache)->streamEnd():static_cast<Arts::SynthModule_base*>(_method_call())->streamEnd();
}

inline float Noatun::WinSkinFFT::bandResolution()
{
	return _cache?static_cast<Noatun::WinSkinFFT_base*>(_cache)->bandResolution():static_cast<Noatun::WinSkinFFT_base*>(_method_call())->bandResolution();
}

inline void Noatun::WinSkinFFT::bandResolution(float _newValue)
{
	 _cache?static_cast<Noatun::WinSkinFFT_base*>(_cache)->bandResolution(_newValue):static_cast<Noatun::WinSkinFFT_base*>(_method_call())->bandResolution(_newValue);
}

inline std::vector<float> * Noatun::WinSkinFFT::scope()
{
	return _cache?static_cast<Noatun::WinSkinFFT_base*>(_cache)->scope():static_cast<Noatun::WinSkinFFT_base*>(_method_call())->scope();
}

#endif /* WINSKINVIS_H */
