# If you want to know all secrets about K-Jofol's resources files,
# Just check out the great tutorial at : http://www.angelfire.com/mo/nequiem/

# Command : About <text>
# Desc.   : This text will appear when the users selects "About ..."
#         : You have 5 lines of text ...
About
About Made by Steve Gedikian for K-Jofol.

# Command : BackgroundImage <Name of .BMP file>
# Desc.   : This is the back image.
BackgroundImage sg.png

# Command : BackgroundImageInactive <Name of .BMP file>
# Desc.   : This is the back image when the window is not selected.
#         : If you do not want this feature, just put the same name as
#         : BackgroundImage
BackgroundImageInactive sg.png

# Command : BackgroundImagePressed[1-3] <Name of .BMP file>
# Desc.   : This is the back images when all the buttons are pressed
#         : Used if you use the BMP option in the buttons options.
#         : You can have 3 backimages so you can do nifty things for the
#         : buttons =)
BackgroundImagePressed1 sgpres1.png
BackgroundImagePressed2 sgpres2.png
BackgroundImagePressed3 sgpres3.png

FontImage sg_text.png
FontSize 5 9
FontSpacing 0
FontTransparent 0
TimeFontImage sg_num.png
TimeFontSize 8 9
TimeFontSpacing 0
TimeFontTransparent 0

# Command : VolumeControlType <BAR/BMP>
# Desc.   : Put BAR if you want a bar style volume control, BMP if you want
#         : to customize it by a BMP animation file ...
# VolumeControlType BAR
# VolumeControlImage btn_vol.bmp
# VolumeControlButton 235 166 275 174 vOLUME
VolumeControlType BMP
VolumeControlImage sgvol.png
VolumeControlImagePosition sgvolpos.png
VolumeControlImageXSize 86
VolumeControlImageNb 83
VolumeControlButton 211 133 296 209 vOLUME

SeekImage sg_seek.png
SeekRegion 91 22 300 127

# Pitch control definition
PitchText 243 93 260 102
PitchControlImage sgpitch.png
PitchControlImageXSize 58
PitchControlImageNb 36
PitchControlButton 222 68 280 125 pITCH
PitchControlImagePosition sgpitchp.png

PitchFontImage sgvolnum.png
PitchFontSize 5 10
PitchFontSpacing 0
PitchFontTransparent 0

# Command : [Option]Button <Position X> <Position Y> <End X> <End Y> <Tooltip Text> <DARKEN/BMP[?]>
# The DARKEN option just dark the button when the user click on it.
# The BMP[?] option use the BackgroundImagePressed[?] defined above.
# Be sure to define a BackgroundImagePressed if you use the BMP option !!
CloseButton 310 116 322 128 Close BMP1
MinimizeButton 306 132 319 140 Minimize BMP1
AboutButton 306 83 334 116 About BMP1
OpenFileButton 25 8 61 26 Open BMP1
StopButton 54 16 81 51 Stop BMP2
PlayButton 28 27 57 56 Play BMP3
#RewindButton 11 49 43 78 FastRewind BMP1
#ForwardButton 45 49 73 77 FastForward BMP1
PreviousSongButton 11 49 43 78 PreviousSong BMP1
NextSongButton 45 49 73 77 NextSong BMP1
PauseButton 9 18 31 51 Pause BMP2
PreferencesButton 267 43 300 51 Options BMP1
EqualizerButton 125 152 135 159 Equalizer BMP1
EqualizerResetButton 175 104 200 112 Reset BMP1
EqualizerOnButton 141 150 152 157 On BMP1
EqualizerOffButton 156 150 167 157 Off BMP1
RepeatButton 278 51 308 59 Repeat BMP1
PlaylistButton 292 67 325 77 Playlist BMP1

# Command : EqualizerWindow <X> <Y> <MaxX> <MaxY> <TipTool> <# of bands> <X-Space between bands>
EqualizerWindow 111 115 180 148 Equalizer 12 6 
# Command : EqualizerBmp <X-Size> <Nb Equalizer> <BMP File>
EqualizerBmp 4 17 sgeq.png

# Inactive Zone
# This put a button that does NOTHING :)
# In fact, this option is very useful for designing the "Spectrum Analyzer" and 
# the "Oscilliscope" buttons because they are not rectangulars.
# Inactive zones for the Spectrum Analyzer button
InactiveZone 91 124 159 136
InactiveZone 99 136 159 152
InactiveZone 113 153 163 166
# Inactive zones for the Oscilloscope butoon
InactiveZone 159 123 198 137
InactiveZone 159 138 190 149
InactiveZone 163 151 177 160
# Remember to put first your inactive zones BEFORE the buttons

# Now that we have put our inactive zones, we could safely put the buttons
SpectrumAnalyzerButton 68 123 167 185 SpectrumAnalyzer
OscilloscopeButton 165 122 211 172 Oscilloscope

# Dock Mode
DockModeButton 243 27 268 36 DockMode BMP1
DockModeRCFile kjofol.dck
# DockModePosition : 0 - Upper Left   1 - Upper Right
#                    2 - Bottom Left  3 - Bottom Right
DockModePosition 0
DockModePositionXY -33 -38
WinshadeModeRCFile kjofol.wsh
WinshadeModePosition 1
WinshadeModePositionXY -405 -9

# Command : FilenameWindow
# Desc.   : This is the window where the file name appears
FilenameWindow 96 80 200 89

MP3KbpsWindow 93 90 110 97
MP3KbpsString 
MP3KhzWindow 135 90 146 97
Mp3KhzString

MP3TimeWindow 124 50 165 59
CurrentTrackWindow 191 90 204 97

# Command : AnalyzerWindow <X> <Y> <MaxX> <MaxY> <TipTool>
# Desc.   : Spectrum Analyzer area. If you doesn't want one, just comment the
#           line ...
AnalyzerWindow 106 61 184 78 Analyzer
# Command : AnalyzerColor <Red> <Green> <Blue>
# Desc.   : Spectrum Analyzer color. Colors range are 0-255.
AnalyzerColor 81 94 81

VolumeFontImage sgvolnum.png
VolumeFontSize 5 10
VolumeFontSpacing 0
VolumeFontTransparent 0
VolumeText 247 168 265 176

IncludeRCFile kjofol.pl
