About : : : phong : : :
About by misery in motion 1999
About misery_in_motion@hotmail.com
About http://misery.mp3s.com.au

BackgroundImage p_main.png
BackgroundImageInactive p_main.png
BackgroundImagePressed1 p_mainback.png


FontImage p_text.png
FontSize 5 9
FontSpacing 1
FontTransparent 0
TimeFontImage p_numbers.png
TimeFontSize 8 11
TimeFontSpacing 1
TimeFontTransparent 0

VolumeControlType BMP
VolumeControlImage p_volbar.png
VolumeControlImagePosition p_volpos.png
VolumeControlImageXSize 37 
VolumeControlImageNb 20
VolumeControlButton 190 53 227 181 vOLUME

SeekRegion 68 55 193 173	
SeekImage p_propos.png

CloseButton 185 41 196 51 Close BMP1
MinimizeButton 174 32 183 42 Minimize BMP1
AboutButton 107 194 147 229 About BMP1
OpenFileButton 237 95 257 130 Open BMP1
StopButton 28 137 53 171 Stop BMP1
PlayButton 24 96 45 130 Play BMP1
#RewindButton 16 35 32 48 FastRewind BMP1
#ForwardButton 33 11 49 25 FastForward BMP1
PreviousSongButton 49 31 76 56 PreviousSong BMP1
NextSongButton 49 172 77 202 NextSong BMP1
PauseButton 32 60 53 91 Pause BMP1
PreferencesButton 198 2 205 11 Options BMP1
#EqualizerButton 76 103 82 107 Equalizer BMP1
EqualizerResetButton 121 150 153 161 Reset BMP1
EqualizerOnButton 98 130 107 142 On BMP1
EqualizerOffButton 146 130 159 141 Off BMP1
RepeatButton 221 66 253 92 Repeat BMP1
PlaylistButton 227 131 252 162 Playlist BMP1

FilenameWindow 86 119 168 129
MP3KbpsWindow 150 108 170 116 
MP3KbpsString 
MP3KhzWindow 88 108 103 116
Mp3KhzString
MP3TimeWindow 105 106 153 122 

AnalyzerWindow 106 89 147 104 Analyzer
AnalyzerColor 88 88 88
EqualizerWindow 109 131 144 145 Equalizer 12 3 
EqualizerBmp 2 12 p_eq.png

DockModeButton 158 23 171 36 DockMode BMP1
DockModeRCFile phong.dck
DockModePosition 0
DockModePositionXY -33 -38
WinshadeModeRCFile phong.wsh
WinshadeModePosition 1
WinshadeModePositionXY -405 -9

PlaylistBmp p_playlist.png
PlaylistBmpPressed p_playback.png
PlaylistWindowText 45 88 177 198
PlaylistWindowFontName Arial
PlaylistWindowFontSize 12
PlaylistWindowFontYSpacing 10
PlaylistWindowNbSelectedTrack 58 211 68 221
PlaylistWindowNbTotalTracks 83 211 93 221

PlaylistWindowLinkButton 148 15 160 25
PlaylistWindowCloseButton 174 31 184 41
PlaylistWindowUpButton 98 67 122 81
PlaylistWindowDownButton 98 207 122 220
PlaylistWindowShuffleButton 157 232 174 248
PlaylistWindowSortButton 115 232 132 248
PlaylistWindowSortInverseButton 137 232 153 248
PlaylistWindowMinimizeButton 161 21 172 32
PlaylistWindowAddButton 48 232 64 248
PlaylistWindowDelButton 70 232 86 248
PlaylistWindowResetButton 91 232 107 248
PlaylistWindowLoadPlaylistButton 41 71 74 78
PlaylistWindowSavePlaylistButton 127 71 164 78
PlaylistWindowSelectionUpButton 185 83 195 90
PlaylistWindowSelectionDownButton 185 199 195 206
PlaylistWindowAboutButton 140 210 193 220
PlaylistWindowPlayButton 84 37 100 53
PlaylistWindowPreviousButton 66 37 82 53
PlaylistWindowNextButton 138 37 153 53
PlaylistWindowPauseButton 101 37 118 53
PlaylistWindowStopButton 120 37 136 53
PlaylistWindowOpenButton 202 210 236 233
PlaylistWindowColor 97 97 97
PlaylistWindowCurrentTrackColor 60 60 60
PlaylistWindowCurrentSelectionColor 150 150 150


