/*
 * mm_accel.h
 * Copyright (C) 2000-2001 Michel Lespinasse <walken@zoy.org>
 * Copyright (C) 1999-2000 Aaron Holtzman <aholtzma@ess.engr.uvic.ca>
 *
 * This file is part of mpeg2dec, a free MPEG-2 video stream decoder.
 * See http://libmpeg2.sourceforge.net/ for updates.
 *
 * mpeg2dec is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * mpeg2dec is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

#ifndef MM_ACCEL_H
#define MM_ACCEL_H

#include <inttypes.h>

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */


/* generic accelerations */
#define MM_ACCEL_MLIB		0x00000001

/* x86 accelerations */
#define MM_ACCEL_X86_MMX	0x80000000
#define MM_ACCEL_X86_3DNOW	0x40000000
#define MM_ACCEL_X86_MMXEXT	0x20000000

/* powerpc accelerations */
#define MM_ACCEL_PPC_ALTIVEC	0x80000000

/* detailed SIMD info */
uint32_t mm_accel (void);

/* true if MMX support */
int mm_support();

#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif 
/* MM_ACCEL_H */
