About .: HexoBronx :.

BackgroundImage inactive.png
BackgroundImagePressed1 active.png
BackgroundImageInactive inactive.png

SplashScreen splash.png


FontImage font.png
FontSize 5 7
FontSpacing 0
FontTransparent 1

TimeFontImage eckig_font.png
TimeFontSize 7 7
TimeFontSpacing 0
TimeFontTransparent 1

PitchFontImage volume_pitch_font.png
PitchFontSize 5 7
PitchFontSpacing 0
PitchFontTransparent 1

VolumeFontImage volume_pitch_font.png
VolumeFontSize 5 7
VolumeFontSpacing 0
VolumeFontTransparent 1


SeekRegion 100 138 222 178
SeekImage mask.png

VolumeControlType BMP
VolumeControlImage volume.png
VolumeControlImagePosition mask.png
VolumeControlImageXSize 33
VolumeControlImageNb 39
VolumeControlButton 16 108 48 146 vol

PitchControlImage pitch.png
PitchControlImagePosition mask.png
PitchControlImageXSize 33
PitchControlImageNb 39
PitchControlButton 272 108 304 146 pitch

CloseButton 233 31 245 42 close BMP1
MinimizeButton 77 32 89 41 min BMP1

PlayButton 124 21 160 59 play BMP1
PauseButton 161 21 197 59 pause BMP1

RewindButton 52 62 111 99 rwd BMP1
ForwardButton 211 62 271 99 fwd BMP1

AboutButton 144 76 176 86 about BMP1
PlaylistButton 137 89 185 102 pl BMP1

RepeatButton 85 119 103 136 repeat BMP1
PreferencesButton 220 118 236 136 pref BMP1

PreviousSongButton 52 156 109 192 prevsong BMP1
NextSongButton 212 156 271 192 nextsong BMP1

StopButton 123 197 197 233 stop BMP1


MP3TimeWindow 144 104 179 111

VolumeText 118 115 138 122

PitchText 190 115 205 122

FilenameWindow 108 125 215 132

AnalyzerWindow 130 134 192 153 analyzer
AnalyzerColor 136 217 144
