#include "kmedia2.idl"
#include "artsflow.idl"

/* the interfaces below are not kept binary compatible */

interface SplayPlayObject : Arts::StreamPlayObject, Arts::SynthModule
{
  async in byte stream indata;

  out audio stream left,right;

};



