


#ifndef __MMX_H
#define __MMX_H


#include <stdio.h>
#include <stdlib.h>

#ifdef __cplusplus
extern "C"
{
#endif /* __cplusplus */


extern int emms();
extern int mm_support();


#ifdef __cplusplus
}
#endif /* __cplusplus */


#endif
