<!DOCTYPE NoatunEqualizer ><noatunequalizer version="1.1.354" name="Metal" level="-100" default="1" >
 <band end="108" start="0" level="162" />
 <band end="217" start="109" level="135" />
 <band end="810" start="218" level="110" />
 <band end="2431" start="811" level="124" />
 <band end="7290" start="2432" level="149" />
 <band end="19999" start="7291" level="175" />
</noatunequalizer>
