<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="kmid" version="2">
<MenuBar>
  <Menu name="view">
    <Action name="play"/>
    <Action name="stop"/>
    <Action name="backward"/>
    <Action name="forward"/>
  </Menu>
</MenuBar>
<ToolBar name="KMid-ToolBar">
  <Action name="play"/>
  <Action name="stop"/>
  <Action name="backward"/>
  <Action name="forward"/>
</ToolBar>
</kpartgui>
