

About idoru xt 1 : vibrocentric
About part of the idoru litestep theme
About by misery in motion 1999
About misery_in_motion@mindless.com
About http://misery.subnet.at

BackgroundImage i_base.png
BackgroundImageInactive i_base.png
BackgroundImagePressed1 i_base2.png


FontImage i_text.png
FontSize 5 6
FontSpacing 0
FontTransparent 0
TimeFontImage i_font.png
TimeFontSize 9 8
TimeFontSpacing 1
TimeFontTransparent 0

VolumeControlType BMP
VolumeControlImage i_vol.png
VolumeControlImagePosition i_volpos.png
VolumeControlImageXSize 51
VolumeControlImageNb 16
VolumeControlButton 41 19 91 69 vOLUME

SeekRegion 58 65 180 186	
SeekImage i_pro.png

CloseButton 123 49 136 61 Close BMP1
MinimizeButton 101 191 114 204 Minimize BMP1
AboutButton 32 79 50 97 About BMP1
OpenFileButton 144 51 161 69 Open BMP1
StopButton 183 88 201 105 Stop BMP1
PlayButton 159 181 186 206 Play BMP1
#RewindButton 16 35 32 48 FastRewind BMP1
#ForwardButton 33 11 49 25 FastForward BMP1
PreviousSongButton 166 63 185 80 PreviousSong BMP1
NextSongButton 185 149 204 166 NextSong BMP1
PauseButton 190 117 208 135 Pause BMP1
PreferencesButton 29 113 47 131 Options BMP1
#EqualizerButton 76 103 82 107 Equalizer BMP1
EqualizerResetButton 116 166 123 172 Reset BMP1
EqualizerOnButton 105 166 114 172 On BMP1
EqualizerOffButton 125 166 137 172 Off BMP1
RepeatButton 35 144 54 160 Repeat BMP1
PlaylistButton 75 185 93 201 Playlist BMP1

FilenameWindow 72 131 169 137
MP3KbpsWindow 74 117 90 122 
#MP3KbpsString 
MP3KhzWindow 79 123 90 129
#Mp3KhzString
MP3TimeWindow 111 118 166 128 

AnalyzerWindow 90 90 149 112 Analyzer
AnalyzerColor 206 208 210
EqualizerWindow 92 139 150 162 Equalizer 12 5 
EqualizerBmp 4 14 i_eq.png

DockModeButton 53 168 71 186 DockMode BMP1
DockModeRCFile vibrocentric.dck
DockModePosition 0
DockModePositionXY -33 -38
WinshadeModeRCFile vibrocentric.wsh
WinshadeModePosition 1
WinshadeModePositionXY -405 -9

PlaylistBmp i_pl.png
PlaylistBmpPressed i_pl2.png
PlaylistWindowText 60 108 176 181
PlaylistWindowFontName Arial
PlaylistWindowFontSize 12
PlaylistWindowFontYSpacing 8
PlaylistWindowNbSelectedTrack 106 186 120 195
PlaylistWindowNbTotalTracks 106 198 120 207

PlaylistWindowLinkButton 148 46 161 59
PlaylistWindowCloseButton 189 82 202 95
PlaylistWindowUpButton 148 86 158 93
PlaylistWindowDownButton 148 96 158 103
PlaylistWindowShuffleButton 136 186 146 196
PlaylistWindowSortButton 124 186 134 196
PlaylistWindowSortInverseButton 148 186 159 196
PlaylistWindowMinimizeButton 124 42 136 55
PlaylistWindowAddButton 124 198 134 208
PlaylistWindowDelButton 136 198 146 208
PlaylistWindowResetButton 148 198 158 208
PlaylistWindowLoadPlaylistButton 88 210 116 219
PlaylistWindowSavePlaylistButton 118 210 147 219
PlaylistWindowSelectionUpButton 44 19 84 38
PlaylistWindowSelectionDownButton 42 39 84 57
PlaylistWindowAboutButton 169 59 183 73
PlaylistWindowPlayButton 157 234 182 257
PlaylistWindowPreviousButton 31 196 44 209
PlaylistWindowNextButton 100 238 112 252
PlaylistWindowPauseButton 75 234 88 247
PlaylistWindowStopButton 50 221 63 234
PlaylistWindowOpenButton 21 165 35 178
PlaylistWindowColor 130 135 139
PlaylistWindowCurrentTrackColor 164 168 171
PlaylistWindowCurrentSelectionColor 81 89 94
