<!DOCTYPE kpartgui>
<kpartgui name="kaudiocreator" version="3">
<ActionProperties>
  <Action name="rip_selected" icon="gear"/>
  <Action name="rip" icon="gear"/>
  <Action name="configure_kaudiocreator" icon="configure"/>
  <Action name="clear_done_jobs" icon="edittrash"/>
  <Action name="eject" icon="player_eject"/>
  <Action name="edit_cd" icon="edit"/>
  <Action name="cddb_now" icon="cdaudio_mount"/>
</ActionProperties>

<MenuBar>
  <Menu name="file"><Text>&amp;Program</Text>
    <Action name="eject"/>
    <Action name="cddb_now"/>
    <Action name="edit_cd"/>
    <Action name="select_all"/>
    <Action name="deselect_all"/>
    <Action name="rip_selected"/>
    <Action name="rip"/>
    <Action name="clear_done_jobs"/>
    <Separator/>
    <Action name="encode_file"/>
    <Separator/>
    <Action name="quit"/>
  </Menu>
  <Menu name="settings">
    <Action name="configuretoolbars" append="configure_merge"/>
    <Action name="configure_kaudiocreator" append="configure_merge"/>
  </Menu>
</MenuBar>

<ToolBar name="Main ToolBar">
  <Action name="cddb_now"/>
  <Action name="edit_cd"/>
  <Action name="rip"/>
  <Action name="eject"/>
</ToolBar>

</kpartgui>
