<!DOCTYPE kpartgui>
<kpartgui name="artsmidimanager.rc" version="1">
<MenuBar>
  <Menu name="add"><text>&amp;Add</text>
    <Action name="add_oss_midi_port"/>
    <Action name="add_arts_midi_output"/>
  </Menu>
</MenuBar>
</kpartgui>
