<!DOCTYPE kpartgui>
<kpartgui name="kaboodle" version="9">
<MenuBar>
	<Menu name="edit">
		<text>&amp;Edit</text>
		<Action name="properties"/>
	</Menu>
</MenuBar>
<Toolbar name="KaboodleToolbar"><text>Kaboodle Toolbar</text>
	<Action name="file_open"/>
	<Action name="options_show_menubar"/>
	<Separator line="true"/>
	<Merge/>
	<Separator line="true"/>
	<Action name="file_quit"/>
</Toolbar>
</kpartgui>
