// This file is generated by kconfig_compiler from libkcddb.kcfg.
// All changes you do to this file will be lost.
#ifndef CONFIGBASE_H
#define CONFIGBASE_H

#include <kconfigskeleton.h>
#include <kdebug.h>

#include <qdir.h>
class KDE_EXPORT ConfigBase : public KConfigSkeleton
{
  public:
    class EnumCachePolicy
    {
      public:
      enum type { OnlyCache, UseCache, IgnoreCache, COUNT };
    };
    class EnumLookupTransport
    {
      public:
      enum type { CDDBP, HTTP, COUNT };
    };
    class EnumSubmitTransport
    {
      public:
      enum type { HTTP, SMTP, COUNT };
    };

    ConfigBase( );
    ~ConfigBase();

    /**
      Set hostname
    */
    void setHostname( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "hostname" ) ))
        mHostname = v;
    }

    /**
      Get hostname
    */
    QString hostname() const
    {
      return mHostname;
    }

    /**
      Set port
    */
    void setPort( int v )
    {
      if (!isImmutable( QString::fromLatin1( "port" ) ))
        mPort = v;
    }

    /**
      Get port
    */
    int port() const
    {
      return mPort;
    }

    /**
      Set cachePolicy
    */
    void setCachePolicy( int v )
    {
      if (!isImmutable( QString::fromLatin1( "cachePolicy" ) ))
        mCachePolicy = v;
    }

    /**
      Get cachePolicy
    */
    int cachePolicy() const
    {
      return mCachePolicy;
    }

    /**
      Set lookupTransport
    */
    void setLookupTransport( int v )
    {
      if (!isImmutable( QString::fromLatin1( "lookupTransport" ) ))
        mLookupTransport = v;
    }

    /**
      Get lookupTransport
    */
    int lookupTransport() const
    {
      return mLookupTransport;
    }

    /**
      Set cacheLocations
    */
    void setCacheLocations( const QStringList & v )
    {
      if (!isImmutable( QString::fromLatin1( "cacheLocations" ) ))
        mCacheLocations = v;
    }

    /**
      Get cacheLocations
    */
    QStringList cacheLocations() const
    {
      return mCacheLocations;
    }

    /**
      Set submitTransport
    */
    void setSubmitTransport( int v )
    {
      if (!isImmutable( QString::fromLatin1( "submitTransport" ) ))
        mSubmitTransport = v;
    }

    /**
      Get submitTransport
    */
    int submitTransport() const
    {
      return mSubmitTransport;
    }

    /**
      Set emailAddress
    */
    void setEmailAddress( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "emailAddress" ) ))
        mEmailAddress = v;
    }

    /**
      Get emailAddress
    */
    QString emailAddress() const
    {
      return mEmailAddress;
    }

    /**
      Set httpSubmitServer
    */
    void setHttpSubmitServer( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "httpSubmitServer" ) ))
        mHttpSubmitServer = v;
    }

    /**
      Get httpSubmitServer
    */
    QString httpSubmitServer() const
    {
      return mHttpSubmitServer;
    }

    /**
      Set httpSubmitPort
    */
    void setHttpSubmitPort( int v )
    {
      if (!isImmutable( QString::fromLatin1( "httpSubmitPort" ) ))
        mHttpSubmitPort = v;
    }

    /**
      Get httpSubmitPort
    */
    int httpSubmitPort() const
    {
      return mHttpSubmitPort;
    }

    /**
      Set smtpPort
    */
    void setSmtpPort( int v )
    {
      if (!isImmutable( QString::fromLatin1( "smtpPort" ) ))
        mSmtpPort = v;
    }

    /**
      Get smtpPort
    */
    int smtpPort() const
    {
      return mSmtpPort;
    }

    /**
      Set smtpUsername
    */
    void setSmtpUsername( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "smtpUsername" ) ))
        mSmtpUsername = v;
    }

    /**
      Get smtpUsername
    */
    QString smtpUsername() const
    {
      return mSmtpUsername;
    }

    /**
      Set useGlobalEmail
    */
    void setUseGlobalEmail( bool v )
    {
      if (!isImmutable( QString::fromLatin1( "useGlobalEmail" ) ))
        mUseGlobalEmail = v;
    }

    /**
      Get useGlobalEmail
    */
    bool useGlobalEmail() const
    {
      return mUseGlobalEmail;
    }

    /**
      Set replyTo
    */
    void setReplyTo( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "replyTo" ) ))
        mReplyTo = v;
    }

    /**
      Get replyTo
    */
    QString replyTo() const
    {
      return mReplyTo;
    }

    /**
      Set smtpHostname
    */
    void setSmtpHostname( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "smtpHostname" ) ))
        mSmtpHostname = v;
    }

    /**
      Get smtpHostname
    */
    QString smtpHostname() const
    {
      return mSmtpHostname;
    }

    /**
      Set submitAddress
    */
    void setSubmitAddress( const QString & v )
    {
      if (!isImmutable( QString::fromLatin1( "submitAddress" ) ))
        mSubmitAddress = v;
    }

    /**
      Get submitAddress
    */
    QString submitAddress() const
    {
      return mSubmitAddress;
    }

  protected:

    // Lookup
    QString mHostname;
    int mPort;
    int mCachePolicy;
    int mLookupTransport;
    QStringList mCacheLocations;

    // Submit
    int mSubmitTransport;
    QString mEmailAddress;
    QString mHttpSubmitServer;
    int mHttpSubmitPort;
    int mSmtpPort;
    QString mSmtpUsername;
    bool mUseGlobalEmail;
    QString mReplyTo;
    QString mSmtpHostname;
    QString mSubmitAddress;

  private:
};

#endif

