<!DOCTYPE kpartgui>
<!--
vim: syntax=xml
-->
<kpartgui name="simpleui" version="1">
<MenuBar>
	<Menu name="file"><text>&amp;File</text>
		<Action name="_file_open"/>
		<Separator lineSeparator="true"/>
		<Action name="_file_properties"/>
		<Separator lineSeparator="true"/>
		<Action name="_file_quit"/>
	</Menu>
	<Menu name="view">
		<Action name="view_playlist"/>
		<Separator lineSeparator="true"/>
		<Action name="half_size" />
		<Action name="normal_size" />
		<Action name="double_size" />
		<Separator lineSeparator="true"/>
		<Action name="fullscreen_mode" />
	</Menu>
	<Menu name="settings" noMerge="1"><text>&amp;Settings</text>
		<Action name="options_show_menubar"/>
		<Action name="options_show_statusbar"/>
		<Separator lineSeparator="true"/>
		<Action name="effects"/>
		<Action name="equalizer"/>
		<Action name="loop_style"/>
		<Separator lineSeparator="true"/>
		<Action name="options_configure"/>
	</Menu>

	<Action name="menu_actions" />
</MenuBar>

</kpartgui>
