<!DOCTYPE kpartgui>
<kpartgui name="kmix" version="3">

<ActionProperties>
    <Action name="hide_kmixwindow" icon="window"/>
</ActionProperties>

<MenuBar>
 <Menu name="file"><text>&amp;File</text>
  <Action name="file_new_tab"/>
  <Action name="file_close_tab"/>
 </Menu>
 <Menu name="settings">
  <Action name="settings_global" append="configure_merge"/>
 </Menu>
 <Menu name="help" append="about_merge"><text>&amp;Help</text>
  <Action name="hwinfo"/>
 </Menu>
</MenuBar>

</kpartgui>
