<!DOCTYPE kpartgui>
<kpartgui name="noatunsystray" version="12">
<Menu name="tray">
	<Action name="file_open"/>
	<Action name="show_playlist"/>
	<Separator lineSeparator="true"/>
	<Action name="back"/>
	<Action name="stop"/>
	<Action name="play"/>
	<Action name="forward"/>
	<Separator lineSeparator="true"/>
	<Action name="loop_style"/>
	<Action name="effects"/>
	<Action name="equalizer"/>
	<Separator lineSeparator="true"/>
	<Action name="options_configure"/>
	<Separator lineSeparator="true"/>
	<Action name="file_quit"/>
</Menu>
</kpartgui>
