<!DOCTYPE kpartgui SYSTEM "kpartgui.dtd">
<kpartgui name="SPL" version="1">

<MenuBar>

<Menu name="file">
	<Action name="add_files" />
	<Action name="add_dir" />
</Menu>

<Menu name="edit">
	<Action name="delete" />
	<Action name="clear" />
	<Separator />
	<Action name="shuffle" />
</Menu>

</MenuBar>

<ToolBar noMerge="1" name="mainToolBar">
	<text>Main Toolbar</text>
	<Action name="add_files" />
	<Action name="add_dir" />
	<Separator />
	<Action name="delete" />
	<Separator />
	<Action name="file_open" />
	<Action name="file_save" />
	<Action name="file_save_as" />
	<Separator />
	<Action name="edit_find" />
</ToolBar>

</kpartgui>
