<!DOCTYPE kpartgui>
<kpartgui name="kaboodle" version="6">
<ActionProperties>
	<Action name="play" icon="1rightarrow"/>
	<Action name="pause" icon="player_pause"/>
	<Action name="stop" icon="player_stop"/>
	<Action name="loop" icon="kaboodleloop"/>
</ActionProperties>
<Toolbar name="KaboodleToolbar"><text>Kaboodle Toolbar</text>
	<Action name="play"/>
	<Action name="pause"/>
	<Action name="stop"/>
	<Separator/>
	<Action name="loop"/>
</Toolbar>
<MenuBar>
<Menu name="edit">
	<Separator/>
	<Action name="play"/>
	<Action name="pause"/>
	<Action name="stop"/>
	<Separator/>
	<Action name="loop"/>
</Menu>
</MenuBar>
</kpartgui>
